@@ -23,9 +23,9 @@
 """
 
 from __future__ import annotations
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Optional, List
 if TYPE_CHECKING:
-    from bale import Bot, Photo, Document
+    from bale import Bot, Photo, Document, Components, RemoveComponents, Price
 
 
 class User:
@@ -63,7 +63,7 @@ class User:
         """:class:`str`"""
         return str(self.user_id)
 
-    async def send(self, text: str, components=None):
+    async def send(self, text: str, components: Optional["Components" | "RemoveComponents"] =None):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_message`.
 
@@ -77,10 +77,19 @@ class User:
         -------
             :class:`bale.Message`
                 On success, the sent Message is returned.
+                
+        Raises
+        ------
+            NotFound
+                Invalid Chat ID.
+            Forbidden
+                You do not have permission to send Message to this chat.
+            APIError
+                Send Message Failed.
         """
-        return await self.bot.send_message(self, text, components)
+        return await self.bot.send_message(self, text, components=components)
 
-    async def send_document(self, document: bytes | str | "Document", caption: str = None):
+    async def send_document(self, document: bytes | str | "Document", *, caption: Optional[str] = None):
         """For the documentation of the arguments, please see :meth:`bale.Bot.send_document`.
 
         Parameters
@@ -89,34 +98,95 @@ class User:
                 Photo
             caption: :class:`str`
                 Message caption
-        Raises
-        ------
-            :class:`bale.Error`
         Returns
         -------
             :class:`bale.Message`
                 On success, the sent Message is returned.
+        Raises
+        ------
+            NotFound
+                Invalid Chat ID.
+            Forbidden
+                You do not have permission to send Document to this chat.
+            APIError
+                Send Document Failed.  
         """
-        return await self.bot.send_document(self, document, caption)
+        return await self.bot.send_document(self, document, caption=caption)
 
-    async def send_photo(self, photo: bytes | str | "Photo", caption: str = None):
+    async def send_photo(self, photo: bytes | str | "Photo", *, caption: Optional[str] = None):
         """For the documentation of the arguments, please see :meth:`bale.Bot.send_photo`.
 
         Parameters
         ----------
             photo: :class:`bytes` | :class:`str` | :class:`bale.Photo`
                 Photo
-            caption: :class:`str`
+            caption: Optional[:class:`str`]
                 Message caption
-        Raises
-        ------
-            :class:`bale.Error`
         Returns
         -------
             :class:`bale.Message`
                 On success, the sent Message is returned.
+        
+        Raises
+        ------
+            NotFound
+                Invalid Chat ID.
+            Forbidden
+                You do not have permission to send Photo to chat.
+            APIError
+                Send Photo Failed.  
         """
-        return await self.bot.send_photo(self, photo, caption)
+        return await self.bot.send_photo(self, photo, caption=caption)
+
+    async def send_invoice(self, title: str, description: str, provider_token: str, prices: List["Price"], *, photo_url: Optional[str] = None, need_name: Optional[bool] = False, need_phone_number: Optional[bool] = False, need_email: Optional[bool] = False, need_shipping_address: Optional[bool] = False, is_flexible: Optional[bool] = True):
+        """
+        For the documentation of the arguments, please see :meth:`bale.Bot.send_invoice`
+
+        Parameters
+        ----------
+            title: str
+                Invoice Title
+            description: str
+                Invoice Description
+            provider_token: str
+                .. note::
+                    You can use 3 methods to receive money:
+                        * Card number
+                        * Port number and acceptor number
+                        * Wallet number "Bale"
+            prices: List[:class:`bale.Price`]
+                A list of prices.
+            photo_url: Optional[:class:`str`]
+                Photo URL of Invoice.
+            need_name: Optional[:class:`bool`]
+                Get a name from "User"?
+            need_phone_number: Optional[:class:`bool`]
+                Get a Phone number from "User"?.
+            need_email: Optional[bool]
+                Get a Email from "User"?.
+            need_shipping_address: Optional[bool]
+                Get a Shipping Address from "User"?.
+            is_flexible: Optional[bool]
+                Is the Invoice Photo Flexible to the Payment button?
+        Returns
+        -------
+            :class:`Bale.Message`:
+                On success, the message sent returned.
+                
+        Raises
+        ------
+            NotFound
+                Invalid Chat ID.
+            Forbidden
+                You do not have permission to send Invoice to this chat.
+            APIError
+                Send Invoice Failed.  
+        """
+        return await self.bot.send_invoice(chat=self, title=title, description=description,
+                                           provider_token=provider_token, prices=prices, photo_url=photo_url,
+                                           need_name=need_name, need_email=need_email,
+                                           need_phone_number=need_phone_number,
+                                           need_shipping_address=need_shipping_address, is_flexible=is_flexible)
 
     @classmethod
     def from_dict(cls, data: dict, bot=None):
